==> flutter_easy-2.6.0.tar.gz: example/lib/modules/example/login/controller.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_easy/flutter_easy.dart';
import 'package:flutter_easy_example/api/constant.dart';
import 'package:flutter_easy_example/generated/l10n.dart';
import 'package:flutter_easy_example/utils/user/model.dart';
import 'package:flutter_easy_example/utils/user/service.dart';

import 'state.dart';

class LoginController extends GetxController {
  final state = LoginState();

  @override
  void onInit() {
    state.phoneNumberController = TextEditingController();
    state.passwordController = TextEditingController();
    state.isChecked = false;
    super.onInit();
  }

  @override
  void onClose() {
    state.phoneNumberController.dispose();
    state.passwordController.dispose();
    super.onClose();
  }

  Future<void> onLoginPressed(BuildContext context) async {
    String phone = state.phoneNumberController.text.trim();
    String password = state.passwordController.text.trim();
    if (phone.isEmpty) {
      // Get.snackbar(S.of(Get.context).example_InputPhoneNumber, "");
      showToast(S.of(context).example_InputPhoneNumber);
      return;
    }

    if (!phone.isCNPhoneNumber) {
      showToast(S.of(context).example_ValidPhoneNumberTip);
      return;
    }

    if (password.isEmpty) {
      showToast(S.of(context).example_InputPassword);
      return;
    }

    if (!state.isChecked) {
      showToast(S.of(context).example_AgreeToContinueTip);
      return;
    }
    Result result = await post(
        path: kApiLogin,
        data: {"phone": phone, "password": password.md5},
        autoLoading: true);
    // if (result.valid) {
    result.fill(UserModel.fromJson({
      "userId": "1",
      "nickname": "flutter${colorWithRandom()}",
      "avatar": ""
    }));

    final service = Get.find<UserService>();
    await service.save(result.model);
    back(true);
    // } else {
    //   showToast(result.message);
    // }
  }
}

==> flutter_easy-3.1.3.tar.gz: example/lib/modules/example/login/controller.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_easy/flutter_easy.dart';
import 'package:flutter_easy_example/api/constant.dart';
import 'package:flutter_easy_example/generated/l10n.dart';
import 'package:flutter_easy_example/store/user/model.dart';
import 'package:flutter_easy_example/store/user/store.dart';

import 'state.dart';

class LoginController extends GetxController {
  final state = LoginState();

  @override
  void onInit() {
    state.phoneNumberController = TextEditingController();
    state.passwordController = TextEditingController();
    state.isChecked = false;
    super.onInit();
  }

  @override
  void onClose() {
    state.phoneNumberController.dispose();
    state.passwordController.dispose();
    super.onClose();
  }

  Future<void> onLoginPressed(BuildContext context) async {
    String phone = state.phoneNumberController.text.trim();
    String password = state.passwordController.text.trim();
    if (phone.isEmpty) {
      // Get.snackbar(S.of(Get.context).example_InputPhoneNumber, "");
      showToast(S.of(context).example_InputPhoneNumber);
      return;
    }

    if (!phone.isCNPhoneNumber) {
      showToast(S.of(context).example_ValidPhoneNumberTip);
      return;
    }

    if (password.isEmpty) {
      showToast(S.of(context).example_InputPassword);
      return;
    }

    if (!state.isChecked) {
      showToast(S.of(context).example_AgreeToContinueTip);
      return;
    }
    Result result = await post(
        path: kApiLogin,
        data: {"phone": phone, "password": password.md5},
        autoLoading: true);
    // if (result.valid) {
    result.fill(UserModel.fromJson({
      "userId": "1",
      "nickname": "flutter${colorWithRandom()}",
      "avatar": ""
    }));

    await UserStore.find.save(result.model);
    offBack(true);
    // } else {
    //   showToast(result.message);
    // }
  }
}
